@@ -368,6 +368,7 @@ class UserLive(models.Model):
             ('view_all_userlives', '可以查看所有学生的录播'),
             ('view_teach_userlives', '可以查看所教的学生的录播'),
             ('view_child_userlives', '可以查看亲子学生的录播'),
+            ('view_expired_userlives', '可以查看超过指定时间的录播'),
         )
 
     def __unicode__(self):
@@ -447,6 +448,7 @@ class UserCourse(models.Model):
         self.save()
 
 
+
 class UserCourseSection(models.Model):
     user_course = models.ForeignKey(UserCourse)
     section = models.ForeignKey(Section)
@@ -642,6 +644,12 @@ class UserCourseSection(models.Model):
             return 0
 
 
+    # 获取学生已通过的课件
+    @classmethod
+    def get_user_pass_sections(cls,user_course):
+        return cls.objects.filter(user_course=user_course,status=2)
+
+
 class UserAssignment(models.Model):
     user_course_section = models.ForeignKey(UserCourseSection)
     content = models.TextField(verbose_name='正文', null=True, blank=True)  # 文字作业
