@@ -101,7 +101,7 @@ urlpatterns = [
     url(r'^live_end_callback$', views.cc_live_end_callback, name='user_live_end_callback'),
     # 直播 完成回调 103
     url(r'^live_finished_callback$', views.cc_live_finished_callback, name='user_live_finished_callback'),
-    url(r'^live_play_logs', views.LivePlayLogs.as_view(), name='play_logs'),
+    # url(r'^live_play_logs', views.LivePlayLogs.as_view(), name='play_logs'),
 
     # 删除直播
     url(r'^delete_user_live/(?P<user_live_id>\d+)$', views.delete_user_live, name='delete_user_live'),
@@ -173,8 +173,13 @@ urlpatterns = [
     # 微信小程序接口
     url(r'weixin_user_course_index$', views.weixin_user_course_index, name='weixin_user_course_index'),
     url(r'weixin_ucs_detail/(?P<ucs_id>\d+)$', views.weixin_ucs_detail, name='weixin_ucs_detail'),
+    url(r'weixin_user_live_list/(?P<user_id>\d+)$', views.weixin_user_live_list, name='weixin_user_live_list'),
+    url(r'weixin_user_live_detail/(?P<live_id>\d+)$', views.weixin_user_live_detail, name='weixin_user_live_detail'),
+    url(r'weixin_user_course_list/(?P<user_id>\d+)$', views.weixin_user_course_list, name='weixin_user_course_list'),
+    url(r'weixin_ucs_list/(?P<user_course_id>\d+)$', views.weixin_ucs_list, name='weixin_ucs_list'),
 
     url(r'test_video$', views.test_video, name='test_video'),
     url(r'uptoken$', views.uptoken, name='uptoken'),
     url(r'tencent_live_callback$', views.tencent_live_callback, name='tencent_live_callback'),
+    url(r'tencent_video_callback$', views.tencent_video_callback, name='tencent_video_callback'),
 ]
