@@ -22,8 +22,10 @@ from .forms import CourseForm, SectionForm, CourseSectionForm, CourseSectionOrde
     UserCourseForm, UserAssignmentForm, UserAssignmentImageForm, SectionVideoForm, PreferenceForm, \
     section_attach_form, UserSectionNoteForm, SectionVideoOrderForm, LivePlayLogsForm, UserLiveCommentForm, \
     CourseSectionQuestionSearchForm
-from .utils import JSONResponse, page_it
-from .cc import create_video_info, get_video_str, get_play_logs
+from .utils import JSONResponse, page_it,can_view_expired_live
+from .cc import create_video_info,get_live_str
+from .cc import get_video_str as get_cc_video_str
+from .qiniu_api import get_video_str as get_qiniu_video_str
 from django.http import JsonResponse, HttpResponseRedirect
 from django.views.decorators.csrf import csrf_exempt
 from django.db import transaction
@@ -34,7 +36,7 @@ from .exports import get_teach_users, get_user_course_section_list
 import cc
 from dss.Serializer import serializer
 from django.core.exceptions import PermissionDenied
-
+from qiniu_api import get_qiniu_token
 from qiniu import Auth
 from qiniu import BucketManager
 
@@ -351,9 +353,9 @@ class VideoDetail(DetailView):
         context = super(VideoDetail, self).get_context_data(**kwargs)
         video_src = None
         if settings.COURSE_VIDEO_PROVIDER_NAME == 'cc':
-            video_src = get_video_str(video.video_id)
+            video_src = get_cc_video_str(video.video_id)
         elif settings.COURSE_VIDEO_PROVIDER_NAME == 'qiniu':
-            video_src = "http://" + settings.QINIU_DOMAIN + "/" + video.file_name
+            video_src = get_qiniu_video_str(video.file_name)
         context["video_src"] = video_src
         context["video_provider_name"] = settings.COURSE_VIDEO_PROVIDER_NAME
         return context
@@ -388,6 +390,11 @@ def prepare_live_video_page_data(live_video_id):
 
 def live_video_detail(request, user_live_id):
     user_live = UserLive.objects.get(pk=user_live_id)
+    if user_live.provider_name=='cc':
+        live_url = get_live_str(user_live.record_video_id)
+    else:
+        live_url=None
+    can_view=can_view_expired_live(request.user,user_live)
     comments = user_live.userlivecomment_set.order_by('-submit_date')
 
     if request.method == "POST":
@@ -398,12 +405,14 @@ def live_video_detail(request, user_live_id):
             comment.user_live = user_live
             comment.save()
             signals.user_live_comment.send(sender=UserLiveComment, user_live=user_live, comment_user=request.user)
-            return redirect(reverse('bee_django_course:live_video_detail', kwargs={'live_video_id': live_video_id}))
+            return redirect(reverse('bee_django_course:live_video_detail', kwargs={'user_live_id': user_live_id}))
     else:
         comment_form = UserLiveCommentForm()
 
     return render(request, 'bee_django_course/live/live_video_detail.html', context={
+        "can_view":can_view,
         'user_live': user_live,
+        'live_url':live_url,
         'comments': comments,
         'comment_form': comment_form,
     })
@@ -438,7 +447,7 @@ def edit_user_live_comment(request, user_live_comment_id):
 
     if request.method == "POST":
         next = reverse('bee_django_course:user_live_video_detail',
-                       kwargs={'live_video_id': comment.user_live.record_video_id})
+                       kwargs={'user_live_id': comment.user_live.id})
         comment_form = UserLiveCommentForm(data=request.POST, instance=comment)
         if comment_form.is_valid():
             comment_form.save()
@@ -456,7 +465,7 @@ def delete_user_live_comment(request, user_live_comment_id):
 
     if request.method == "POST":
         next = reverse('bee_django_course:user_live_video_detail',
-                       kwargs={'live_video_id': comment.user_live.record_video_id})
+                       kwargs={'user_live_id': comment.user_live.id})
         comment.delete()
         return JsonResponse(data={
             'message': '操作成功',
@@ -503,7 +512,7 @@ class CCVideoInfoCreate(TemplateView):
         description = request.POST.get("description")
         filename = request.POST.get("filename")
         filesize = request.POST.get("filesize")
-        res = create_video_info(title, filename, filesize, settings.COURSE_CC_CATEGORYID)
+        res = create_video_info(title, filename, filesize)
         return JSONResponse(json.dumps(res, ensure_ascii=False))
 
 
@@ -531,35 +540,18 @@ def cc_video_callback(request):
     return
 
 
-# 上传视频到七牛，需要先获取的token
-def get_qiniu_token(key):
-    access_key = settings.QINIU_AK
-    secret_key = settings.QINIU_SK
-    # 构建鉴权对象
-    q = Auth(access_key, secret_key)
-    # 要上传的空间
-    bucket_name = settings.QINIU_BUCKET_NAME
-    # key 上传后保存的文件名
-
-    # 生成上传 Token，可以指定过期时间等
-    # 上传策略示例
-    # https://developer.qiniu.com/kodo/manual/1206/put-policy
-    policy = {
-        # 'callbackUrl':'https://requestb.in/1c7q2d31',
-        # 'callbackBody':'filename=$(fname)&filesize=$(fsize)'
-        # 'persistentOps':'imageView2/1/w/200/h/200'
-    }
-    # 3600为token过期时间，秒为单位。3600等于一小时
-    token = q.upload_token(bucket_name, key=key.encode('utf-8'), expires=3600, policy=policy)
-    return token
 
 
 def uptoken(request):
     key = request.GET.get('key')
     token = get_qiniu_token(key)
+    if hasattr(settings, "QINIU_CONFIG"):
+        domain=settings.QINIU_CONFIG.domain
+    else:
+        domain=None
     return JsonResponse(data={
         'uptoken': token,
-        'domain': settings.QINIU_DOMAIN,
+        'domain': domain,
     })
 
 
@@ -1385,22 +1377,22 @@ def cc_live_end_callback(request):
     return JsonResponse(json.dumps(res, ensure_ascii=False), safe=False)
 
 
-class LivePlayLogs(TemplateView):
-    template_name = 'bee_django_course/live/play_logs.html'
-
-    def get_context_data(self, **kwargs):
-        context = super(LivePlayLogs, self).get_context_data(**kwargs)
-        context["form"] = LivePlayLogsForm()
-        print('a', context["form"])
-        return context
-
-    def post(self, request, *args, **kwargs):
-        form = LivePlayLogsForm(request.POST)
-        if form.is_valid():
-            video_id = form.cleaned_data['a']
-            date = form.cleaned_data['date']
-            total, play_log = get_play_logs(video_id=video_id, date=date)
-            print(total, play_log)
+# class LivePlayLogs(TemplateView):
+#     template_name = 'bee_django_course/live/play_logs.html'
+#
+#     def get_context_data(self, **kwargs):
+#         context = super(LivePlayLogs, self).get_context_data(**kwargs)
+#         context["form"] = LivePlayLogsForm()
+#         print('a', context["form"])
+#         return context
+#
+#     def post(self, request, *args, **kwargs):
+#         form = LivePlayLogsForm(request.POST)
+#         if form.is_valid():
+#             video_id = form.cleaned_data['a']
+#             date = form.cleaned_data['date']
+#             total, play_log = get_play_logs(video_id=video_id, date=date)
+#             print(total, play_log)
             # return redirect(reverse_lazy('bee_django_crm:preuser_application_update_preuser', kwargs={'pk': preuser.id}))
 
 
@@ -1810,22 +1802,30 @@ def delete_user_live(request, user_live_id):
 # 微信小程序接口
 # 课程页
 def weixin_user_course_index(request):
-    user = request.token_user
+    user = request.user
     if not user:
         return JsonResponse(data={
+            "errCode":1,
             'msg': '无效的用户',
         })
 
     ucs = get_user_last_course_section(user)
     if not ucs:
         return JsonResponse(data={
+            "errCode":0,
             'msg': '没有学习中的课程',
+            "ucs_detail":None,
+            "course_detail":None,
+            "section_detail":None
         })
 
     return JsonResponse(data={
+        "errCode":0,
         'user_name': user.first_name or user.username,
         'section_detail': serializer(ucs.section, output_type='json',
-                                     datetime_format='string', exclude_attr=['image', 'info']),
+                                     datetime_format='string', exclude_attr=['image']),
+        "course_detail":serializer(ucs.user_course.course,output_type='json',
+                                     datetime_format='string', exclude_attr=['teacher_id','image']),
         'ucs_detail': serializer(ucs, output_type='json', datetime_format='string'),
         'msg': 'OK',
     })
@@ -1837,21 +1837,75 @@ def weixin_ucs_detail(request, ucs_id):
         ucs = UserCourseSection.objects.get(pk=ucs_id)
         videos = []
         for e in ucs.section.sectionvideo_set.all():
-            videos.append({'vid': e.video.video_id, 'titile': e.video.title})
+            videos.append({'vid': e.video.video_id, 'title': e.video.title})
 
         return JsonResponse(data={
-            'rc': 0,
+            'errCode': 0,
+            'errMsg': '成功',
+            'ucs_detail': serializer(ucs, output_type='json', datetime_format='string'),
             'section_detail': serializer(ucs.section, output_type='json', datetime_format='string',
                                          exclude_attr=['image']),
             'section_videos': serializer(videos, output_type='json')
         })
     except UserCourseSection.DoesNotExist:
         return JsonResponse(data={
-            'rc': -1,
-            'msg': '用户课程(UCS)不存在',
+            'JsonResponse': 1,
+            'errMsg': '用户课程(UCS)不存在',
         })
 
 
+# 小程序 用户课程列表
+def weixin_user_course_list(request, user_id):
+    try:
+        user = User.objects.get(pk=user_id)
+        user_course_list = user.usercourse_set.all()
+
+        return JsonResponse(data={
+            'rc': 0,
+            'user_course_list': serializer(user_course_list, output_type='json', foreign=True, datetime_format='string')
+        })
+    except User.DoesNotExist:
+        return JsonResponse(data={
+            'rc': -1,
+            'msg': '用户不存在'
+        })
+
+
+# 小程序 用户课程详情（课件列表）
+def weixin_ucs_list(request, user_course_id):
+    try:
+        user_course = UserCourse.objects.get(pk=user_course_id)
+        ucs_list = get_user_course_section_list(user_course)
+
+        return JsonResponse(data={
+            'rc': 0,
+            'ucs_list': serializer(ucs_list, output_type='json', datetime_format='string',
+                                   foreign=True, exclude_attr=['user_course'])
+        })
+    except UserCourse.DoesNotExist:
+        return JsonResponse(data={
+            'rc': -1,
+            'msg': '用户课程不存在'
+        })
+
+
+# 小程序 用户录播列表，最近20条
+def weixin_user_live_list(request, user_id):
+    user_live_list = UserLive.objects.filter(user_id=user_id, status=1).order_by('-created_at')[:20]
+
+    return JsonResponse(data={
+        'errCode': 0,
+        'user_live_list': serializer(user_live_list, output_type='json', datetime_format='string')
+    })
+
+# 小程序 用户录播详情
+def weixin_user_live_detail(request,live_id):
+    user_live=UserLive.objects.get(id=live_id)
+    return JsonResponse(data={
+        'errCode': 0,
+        'user_live_detail': serializer(user_live, output_type='json', datetime_format='string')
+    })
+
 def test_video(request):
     return render(request, 'bee_django_course/test_video.html')
 
@@ -1879,24 +1933,38 @@ def tencent_live_callback(request):
     # {"appid":1256935119,"channel_id":"aa","duration":3,"end_time":1562658284,"end_time_usec":453420,"event_type":100,"file_format":"mp4","file_id":"5285890791305792056","file_size":420382,"media_start_time":3801,"record_bps":0,"record_file_id":"5285890791305792056","start_time":1562658283,"start_time_usec":375858,"stream_id":"aa","stream_param":"txSecret=e939142722088dc59849bb82fc4d0fd1&txTime=5D24B9FF","task_id":"18288319047887901972","video_id":"1256935119_55156dda6162403abd8860da89d07ab6","video_url":"http://1256935119.vod2.myqcloud.com/8f802c2cvodcq1256935119/b3d83b505285890791305792056/f0.mp4"}
     print("tencent_live_callback: ")
 
+    _dict=json.loads(request.body)
+    try:
+        username=_dict["stream_id"]
+        video_url=_dict["video_url"]
+        start_time=int(_dict["start_time"])
+        end_time=int(_dict["end_time"])
+        duration=_dict["duration"]
+
+        user=User.objects.get(username=username)
+        userlive=UserLive()
+        userlive.provider_name="tencent"
+        userlive.replay_url=video_url
+        userlive.start_time=datetime.datetime.fromtimestamp(start_time)
+        userlive.end_time=datetime.datetime.fromtimestamp(end_time)
+        userlive.user=user
+        userlive.duration=duration
+        userlive.status=1
+        userlive.record_status=10
+        userlive.save()
+        live_finish(userlive)
+        return JsonResponse({
+            "code": 0,
+        })
+    except Exception as e:
+        print(e)
+
+
+@csrf_exempt
+def tencent_video_callback(request):
+    print("tencent_video_callback: ")
     print request.body
-    username=request.body["stream_id"]
-    video_url=request.body["video_url"]
-    start_time=request.body["start_time"]
-    end_time=request.body["end_time"]
-    duration=request.body["duration"]
 
-    user=User.objects.get(username=username)
-    userlive=UserLive()
-    userlive.provider_name="tencent"
-    userlive.replay_url=video_url
-    userlive.start_time=datetime.datetime.fromtimestamp(start_time)
-    userlive.end_time=datetime.datetime.fromtimestamp(end_time)
-    userlive.user=user
-    userlive.duration=duration
-    userlive.status=1
-    userlive.save()
-    live_finish(userlive)
     return JsonResponse({
         "code": 0,
     })
